'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.desc = exports.command = undefined;

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _ora = require('ora');

var _ora2 = _interopRequireDefault(_ora);

var _nodeFetch = require('node-fetch');

var _nodeFetch2 = _interopRequireDefault(_nodeFetch);

var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

var _inquirer = require('inquirer');

var _inquirer2 = _interopRequireDefault(_inquirer);

var _username = require('username');

var _username2 = _interopRequireDefault(_username);

var _cpy = require('cpy');

var _cpy2 = _interopRequireDefault(_cpy);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _name = require('../validate/name');

var _name2 = _interopRequireDefault(_name);

var _checkSystem = require('../validate/check-system');

var _checkSystem2 = _interopRequireDefault(_checkSystem);

var _dir = require('../init/dir');

var _dir2 = _interopRequireDefault(_dir);

var _json = require('../init/json');

var _json2 = _interopRequireDefault(_json);

var _git = require('../init/git');

var _git2 = _interopRequireDefault(_git);

var _npm = require('../init/npm');

var _npm2 = _interopRequireDefault(_npm);

var _changeDir = require('../util/change-dir');

var _changeDir2 = _interopRequireDefault(_changeDir);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var command = exports.command = 'init [dir]';
var desc = exports.desc = 'Creates a new electron application';

var builder = exports.builder = {
  dir: {
    default: undefined
  }
};

var handler = exports.handler = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(argv) {
    var initSpinner, request, versions, latest, formatedVersions, questions, _ref2, electronVersion, boilerPlate, rest, dirSpinner, name, createdDir, dependencies, scripts, main;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            initSpinner = (0, _ora2.default)('Getting versions').start();
            _context.next = 3;
            return (0, _nodeFetch2.default)('https://registry.npmjs.org/electron').then(function (res) {
              return res.json();
            });

          case 3:
            request = _context.sent;
            versions = (0, _keys2.default)(request.versions);


            versions.sort(function (a, b) {
              return _semver2.default.lt(a, b) ? 1 : -1;
            });

            latest = versions[0];
            formatedVersions = versions.map(function (v) {
              return '(' + v + ')';
            }).join(' ');
            _context.next = 10;
            return (0, _checkSystem2.default)();

          case 10:
            _context.t0 = { type: 'input',
              name: 'name',
              message: 'Which name would you like for you proyect',
              validate: _name2.default,
              when: argv.dir === undefined
            };
            _context.t1 = {
              type: 'input',
              name: 'version',
              message: 'Project version',
              default: '0.0.0',
              validate: function validate(version) {
                return _semver2.default.valid(version) ? true : 'Incorrect version fomat';
              }
            };
            _context.t2 = {
              type: 'input',
              name: 'license',
              message: 'License',
              default: 'MIT'
            };
            _context.t3 = {
              type: 'input',
              name: 'description',
              message: 'Description'
            };
            _context.next = 16;
            return (0, _username2.default)();

          case 16:
            _context.t4 = _context.sent;
            _context.t5 = {
              type: 'input',
              message: 'Author',
              name: 'author',
              default: _context.t4
            };
            _context.t6 = {
              type: 'input',
              name: 'electronVersion',
              message: 'What version of electron would you like to install? latest is',
              default: latest,
              validate: function validate(version) {
                return versions.find(function (v) {
                  return v === version;
                }) ? true : 'That version is unavailable available versions ' + formatedVersions;
              }
            };
            _context.t7 = {
              type: 'confirm',
              name: 'boilerPlate',
              message: 'Would you like to install with the provided boilerplate?',
              when: function when(answers) {
                return answers.electronVersion === latest;
              }
            };
            questions = [_context.t0, _context.t1, _context.t2, _context.t3, _context.t5, _context.t6, _context.t7];


            initSpinner.succeed();

            _context.next = 24;
            return _inquirer2.default.prompt(questions);

          case 24:
            _ref2 = _context.sent;
            electronVersion = _ref2.electronVersion;
            boilerPlate = _ref2.boilerPlate;
            rest = (0, _objectWithoutProperties3.default)(_ref2, ['electronVersion', 'boilerPlate']);
            dirSpinner = (0, _ora2.default)('Initializing Directory').start();
            name = argv.dir || rest.name;
            _context.next = 32;
            return (0, _dir2.default)(name);

          case 32:
            createdDir = _context.sent;
            dependencies = { electron: '^' + electronVersion };
            scripts = { start: 'electron .' };
            main = 'main.js';

            if (!boilerPlate) {
              _context.next = 39;
              break;
            }

            _context.next = 39;
            return (0, _cpy2.default)(['templates/index.html', 'templates/main.js'], createdDir);

          case 39:
            _context.next = 41;
            return (0, _json2.default)(createdDir, (0, _extends3.default)({ name: name, dependencies: dependencies, scripts: scripts, main: main }, rest));

          case 41:
            _context.next = 43;
            return (0, _changeDir2.default)(createdDir);

          case 43:
            _context.next = 45;
            return (0, _git2.default)();

          case 45:
            _context.next = 47;
            return (0, _npm2.default)();

          case 47:

            dirSpinner.succeed();

            console.log(_chalk2.default.green('To start enter the ' + name + ' directory, then you can run npm start to run your electron application'));

          case 49:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  }));

  return function handler(_x) {
    return _ref.apply(this, arguments);
  };
}();